@@ -44,7 +44,7 @@ global_update_rules = {
     # commonsense  reasoning
     '#IF($is_student=True)': '#SET($is_adult=False)',
     '#IN(roommate, $lives_with)': '#SET($is_adult=True)',
-    '#IF($children)': '#SET($is_adult=True) #SET($has_children=True) #CHILDREN',
+    '#IF($children)': '#SET($is_adult=True) #SET($has_children=True)',
     '#IF($in_college=True)': '#SET($is_adult=False) #SET($is_child=False)',
     '#IF($lives_alone=True)': '#SET($is_child=False) #SET($lives_with, #U())',
     '#IF($is_employed=True)': '#SET($is_child=False)',
