@@ -62,7 +62,7 @@ cdf.add_system_transition('root', 'sibling:start', '')
 
 cdf.add_system_transition('root', 'relationships:dating', '')
 cdf.add_system_transition('root', 'relationships:dating->relationships:relationship_length', '', score=10.0)
-cdf.add_system_transition('root', 'relationships:marriage', '')
+cdf.add_system_transition('root', 'relationships:marriage', '',score=100)
 cdf.add_system_transition('root', 'relationships:marriage->relationships:how_long_married', '', score=10.0)
 
 cdf.add_system_transition('root', 'baby:start', '')
@@ -84,7 +84,7 @@ cdf.add_system_transition('root', 'cvopen:start', '',score=2.0)
 class Known(Macro):
 
     def run(self, ngrams, vars, args):
-        if not 'existing_vars' in vars or vars['existing_vars'] == 'None':
+        if 'existing_vars' not in vars or vars['existing_vars'] == 'None':
             return False
         for arg in args:
             if not _term_op_term(arg, vars["existing_vars"]):
@@ -95,7 +95,7 @@ class Known(Macro):
 
 central_kb = cdf.component('SYSTEM').knowledge_base()
 for component in cdf.components():
-    component.load_update_rules(global_update_rules)
+    component.load_update_rules(global_update_rules, score=999999999)
     component.load_global_nlu(personal_nlu, 5.0)
     component.add_macros({'CNC': emora_stdm.CheckNotComponent(cdf), "KNOWN": Known()})
     component.add_macros(macros)
@@ -104,13 +104,13 @@ if __name__ == '__main__':
     #cdf.precache_transitions()
     #cdf.run(debugging=False)
     deb = True
-    cdf.controller().vars()["sibling"] = "None"
+    cdf.controller().vars()["is_adult"] = "True"
     while True:
         cdf.controller().set_speaker(DialogueFlow.Speaker.USER)
         cdf.user_turn(input('U: '),debugging=deb)
         cdf.controller().set_speaker(DialogueFlow.Speaker.SYSTEM)
         vars = cdf.controller().vars()
-        # for k, v in vars.items():
-        #     if '_' != k[0]:
-        #         print('{:<15} {}'.format(k + ':', v))
+        for k, v in vars.items():
+            if '_' != k[0]:
+                print('{:<15} {}'.format(k + ':', v))
         print('E:', cdf.system_turn(debugging=deb))
