@@ -1,10 +1,10 @@
 
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow
+from emora._flows._central_knowledge import central_knowledge
 
 
-coronavirus = DialogueFlow('_local_start')
-coronavirus.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
+coronavirus = DialogueFlow('_local_start', kb=central_knowledge)
 coronavirus.add_system_transition('_local_start', 'start', '')
 
 system = {
