@@ -1,10 +1,9 @@
 
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow
+from emora._flows._central_knowledge import central_knowledge
 
-
-sibling = DialogueFlow('_local_start')
-sibling.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
+sibling = DialogueFlow('_local_start', kb=central_knowledge)
 sibling.add_system_transition('_local_start', 'start', '')
 
 siblings = {
